from arraydebug.core import (  # noqa
    recover_repr,
    inject_repr,
    register_reprs,
    register_repr,
    repr_fn_table,
)

__author__ = """Qimai Li"""
__email__ = "liqimai@qq.com"
__version__ = "0.1.1"


register_reprs()
inject_repr()
